package agora.database;

import java.io.IOException;
import java.io.Serializable;
import java.util.List;

import org.apache.http.client.ClientProtocolException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.AnnotationConfiguration;

import agora.classes.Course;
import agora.classes.ItemAgenda;
import agora.classes.Notification;
import agora.classes.Space;
import agora.classes.User;

public class DBconnector implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private Session session;
	private SessionFactory factory;
//	private Query query;

	public DBconnector() {

		AnnotationConfiguration config = new AnnotationConfiguration();
		config.addAnnotatedClass(User.class);
		config.addAnnotatedClass(Course.class);
		config.addAnnotatedClass(ItemAgenda.class);
		config.addAnnotatedClass(Space.class);
		config.addAnnotatedClass(Notification.class);
		config.configure("hibernate.cfg.xml");
		factory = config.buildSessionFactory();
		session = factory.openSession();
	}

	/**
	 * Funci per a fer LOGIN al sistema
	 * 
	 * @param username
	 * @param password
	 * 
	 */
	public boolean login(String username, String password) {

		session.beginTransaction();
		User result = (User) session.get(User.class, username);

		if (result == null) {
			System.out.println("Innexistent");
			return false;
		} else if (result.getPassword().equals(password)) {
			return true;
		} else {
			System.out.println("Contrassenya incorrecte");
			return false;
		}
	}

	/**
	 * Funci per a fer OBTENIR usuari
	 * 
	 * @param username
	 * 
	 */
	public User getUser(String username) {
		session.beginTransaction();
		User result = (User) session.get(User.class, username);
		if (result == null) {
			System.out.println("Innexistent");
			return null;
		} else {
			return result;
		}
	}

	/**
	 * Funci per a fer OBTENIR llista de Cursos
	 * 
	 * 
	 */
	public List<Course> getCourses() {
		session.beginTransaction();
		Query query = session.createQuery("from Course");
		List<Course> list = query.list();
		return list;
	}

	/**
	 * Funci per a fer OBTENIR llista de usuaris si Course == null RETORNA TOT
	 * UTILITZAR DE MOMENT COM A NULL
	 * 
	 * @param Course
	 * 
	 */
	public List<User> getCourseUsers(String course) {
		session.beginTransaction();
		List<User> list = null;
		if (course == null) {
			// Si es null, tenim que seleccionar tots els usuaris de la taula Users
			Query query = session.createQuery("from User");
			list = query.list();
		}else{
			// Si s'especifica un Curs Concret, tenim que agafar la llista d'users
			Course result = (Course) session.get(Course.class, course);
			list = result.getTeachers();
		}
		return list;
	}
	
	/**
	 * Funci per a fer OBTENIR TOTA la llista de NOTIFICACIONS
	 * 
	 * @param Course
	 * 
	 */
	public List<Notification> getNotifications() {
		session.beginTransaction();
		Query query = session.createQuery("from Notification order by date");
		List<Notification> list = query.list();
		return list;
	}
	
	/**
	 * Funci per a fer POSAR UNA Notificaci
	 * 
	 * @param Course
	 * 
	 */
	public void setNotification(Notification n) {
		session.beginTransaction();
		session.save(n);
		session.getTransaction().commit();
	}

	public List<Space> getSpaces() {
		session.beginTransaction();
		Query query = session.createQuery("from Space");
		List<Space> list = query.list();
		return list;
	}
}
